@@ -11,7 +11,7 @@ FileInfo = namedtuple('FileInfo', _file_info)
 FileInfo.__new__.__defaults__ = ('',) * len(_file_info)
 UserInfo = namedtuple('UserInfo', ['id', 'nick_name', 'ctime', 'phone', 'drive_id'])
 UserInfo.__new__.__defaults__ = ('',) * 5
-ShareInfo = namedtuple('ShareInfo', ['name', 'content_hash', 'content_hash_name', 'size', 'path'])
-ShareInfo.__new__.__defaults__ = ('',) * 5
+ShareInfo = namedtuple('ShareInfo', ['name', 'content_hash', 'proof_code', 'content_hash_name', 'size', 'path'])
+ShareInfo.__new__.__defaults__ = ('',) * 6
 AlibumInfo = namedtuple('AlibumInfo', ['drive_name', 'drive_id'])
 AlibumInfo.__new__.__defaults__ = ('',) * 2
